package com.supervision.manage.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.supervision.manage.service.ConfigTreatmentPlanManageService;
import com.supervision.model.ConfigTreatmentPlan;
import com.supervision.service.ConfigTreatmentPlanService;
import com.supervision.vo.manage.TreeNode;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

@Service
@RequiredArgsConstructor
public class ConfigTreatmentPlanManageServiceImpl implements ConfigTreatmentPlanManageService {

    private final ConfigTreatmentPlanService configTreatmentPlanService;

    @Override
    public List<TreeNode> queryTree(Integer disposalMethod) {
        List<ConfigTreatmentPlan> list = configTreatmentPlanService.lambdaQuery().eq(!Objects.isNull(disposalMethod),
                ConfigTreatmentPlan::getDisposalPlan, disposalMethod).list();

        if (CollUtil.isEmpty(list)){
            return CollUtil.newArrayList();
        }

        TreeNode root = new TreeNode();
        for (ConfigTreatmentPlan configTreatmentPlan : list) {
            String id = configTreatmentPlan.getId();
            String disposalPlan = configTreatmentPlan.getDisposalPlan();
            String firstMeasures = configTreatmentPlan.getFirstMeasures();
            String secondMeasures = configTreatmentPlan.getSecondMeasures();

            // 一级节点
            if (StrUtil.isEmpty(disposalPlan)){
                continue;
            }
            TreeNode disposalPlanNode = root.findChildByName(disposalPlan);
            if (null == disposalPlanNode){
                disposalPlanNode = new TreeNode(StrUtil.isNotEmpty(firstMeasures) ? null : id, disposalPlan);
                root.getOrDefaultChild().add(disposalPlanNode);
            }

            // 二级节点
            if (StrUtil.isEmpty(firstMeasures)){
                continue;
            }
            TreeNode firstMeasuresNode = disposalPlanNode.findChildByName(firstMeasures);
            if (null == firstMeasuresNode){
                firstMeasuresNode = new TreeNode(StrUtil.isNotEmpty(secondMeasures) ? null : id,firstMeasures);
                disposalPlanNode.getOrDefaultChild().add(firstMeasuresNode);
            }


            // 三级节点
            if (StrUtil.isEmpty(secondMeasures)){
                continue;
            }
            TreeNode secondMeasuresNode = firstMeasuresNode.findChildByName(secondMeasures);
            if (null == secondMeasuresNode){
                secondMeasuresNode = new TreeNode(id,secondMeasures);
                firstMeasuresNode.getOrDefaultChild().add(secondMeasuresNode);
            }
        }

        return root.getChild();
    }

    @Override
    public List<ConfigTreatmentPlan> queryList(Integer disposalMethod) {
        return null;
    }

    @Override
    public TreeNode findById(String id) {
        return null;
    }

}
