package com.supervision.manage.service.impl;

import cn.hutool.core.lang.Assert;
import cn.hutool.core.util.StrUtil;
import com.supervision.manage.service.DiseaseTreatmentPlanManageService;
import com.supervision.model.ConfigTreatmentPlan;
import com.supervision.model.DiseaseTreatmentPlan;
import com.supervision.service.DiseaseTreatmentPlanService;
import com.supervision.vo.manage.DiseaseTreatmentPlanResVo;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.List;
@Service
@RequiredArgsConstructor
public class DiseaseTreatmentPlanManageServiceImpl implements DiseaseTreatmentPlanManageService {

    private final DiseaseTreatmentPlanService diseaseTreatmentPlanService;
    @Override
    public List<DiseaseTreatmentPlanResVo> queryListByDiseaseId(String diseaseId) {

        Assert.notEmpty(diseaseId,"疾病id不能为空");
        return diseaseTreatmentPlanService.queryListByDiseaseId(diseaseId);
    }

    @Override
    public DiseaseTreatmentPlan saveTreatmentPlan(DiseaseTreatmentPlan diseaseTreatmentPlan) {

        assertDiseaseTreatmentPlan(diseaseTreatmentPlan);

        diseaseTreatmentPlanService.save(diseaseTreatmentPlan);

        return diseaseTreatmentPlan;

    }

    @Override
    public void batchSaveTreatmentPlan(List<DiseaseTreatmentPlan> diseaseTreatmentPlanList) {
        Assert.notEmpty(diseaseTreatmentPlanList,"数据不能为空");
        diseaseTreatmentPlanList.forEach(this::assertDiseaseTreatmentPlan);

        diseaseTreatmentPlanService.saveBatch(diseaseTreatmentPlanList);
    }

    @Override
    public boolean deleteDiseaseTreatmentPlan(String id) {
        Assert.notEmpty(id,"id不能为空");

        return diseaseTreatmentPlanService.removeById(id);
    }


    private void assertDiseaseTreatmentPlan(DiseaseTreatmentPlan diseaseTreatmentPlan){

        Assert.isTrue(StrUtil.isEmpty(diseaseTreatmentPlan.getId()),"id需要为空");

        Assert.notEmpty(diseaseTreatmentPlan.getDiseaseId(),"疾病id不能为空");

        Assert.notEmpty(diseaseTreatmentPlan.getPlanId(),"处置计划id不能为空");
    }
}
